<?php

namespace MyApp\Service;

use MyApp\Model\ServersModel;
use MyApp\Model\GroupsModel;
use MyApp\Core\Model;
use Exception;

class ServersService
{
    /**
     * @return ServersModel[]|null
     *
     * @throws Exception
     */
    public function getTableData(): ?array
    {
        $models = ServersModel::find(null, null, '1 = 1');
        $records = [];
        foreach ($models as $model) {
            /** @var ServersModel $model */
            if ($group_id = $model->getGroup()) {
                $records[] = $group_id;
            }
        }
        if (count($records)) {
            if ($groups = GroupsModel::find($records)) {
                $groups_names = [];
                /** @var GroupsModel $group */
                foreach ($groups as $group) {
                    $groups_names[$group->getId()] = $group->getName();
                }

                foreach ($models as $model) {
                    if (array_key_exists($model->getGroup(), $groups_names)) {
                        $model->{'group_name'} = $groups_names[$model->getGroup()];
                    }
                }
            }
        }

        return $models;
    }

    public function getServer($id): ?ServersModel
    {
        $model = ServersModel::find([$id], null, null, [], '', '1');
        if (!empty($model)) {
            return $model[0];
        }

        return null;
    }

    public function updateServer(int $id, string $name, string $ip, int $group)
    {
        if ($model = $this->getServer($id)) {
            $model->setName($name)
                  ->setIp($ip)
                  ->setGroup($group ? $group : null);
            Model::save([$model]);
        }

        return $model;
    }

    public function deleteServer(int $id): void
    {
        if ($model = $this->getServer($id)) {
            $arr = [$model];
            Model::delete($arr);
        }
    }

    public function addServer(string $name, string $ip, int $group)
    {
        $model = (new ServersModel())->setName($name)
                                     ->setIp($ip)
                                     ->setGroup($group ? $group : null);
        Model::save([$model]);

        return $model;
    }
}
